
#' % Formation Statistiques - Concepts de base : exercices
#' % Gilles San Martin - gilles.sanmartin@gmail.com
#' % Septembre 2013 
#' 
#' ---------------------------------------------------------------------------------------------------------------


#+ echo = FALSE
library(knitr)
# source("/home/gilles/stats/makereport.R")
# makereport("Formation_Stats_2_Intro_exercices.R", output = c("latex"), wd = "/home/gilles/stats/Formation_R_stats/Formation_Stats_2_Intro/Exercices")


# Enoncés sans les réponses : 
opts_chunk$set(dev = c("png", "pdf"), fig.width = 10/2.54, fig.height= 10/2.54, echo=FALSE, results= "hide", fig.keep = "none", warning = FALSE, error = FALSE, message = FALSE)

# Enoncés, corrections sans output: 
# opts_chunk$set(dev = c("png", "pdf"), fig.width = 10/2.54, fig.height= 10/2.54, echo=TRUE, results= "hide", fig.keep = "none", warning = FALSE, error = FALSE, message = FALSE)

# Enoncés, corrections avec output: 
# opts_chunk$set(dev = c("png", "pdf"), fig.width = 10/2.54, fig.height= 10/2.54, echo=TRUE, results= "markup", warning = TRUE, error = TRUE, message = TRUE)


#' Le but de cette série d'exercices est de se familiariser avec les concepts de base de 
#' l'inférence statistique : 
#' Intervalles de confiance, erreur standard, tests d'hypothèse nulle.  
#' On a fait le choix d'utiliser non seulement les approches classiques basées 
#' sur des distributions de probabilités théoriques mais aussi des méthodes plus récentes de 
#' rééchantillonnage par ordinateur (permutation, bootstrap) qui sont moins basées sur la 
#' théorie mathématique.

#' 
#' <!-- page break -->

#' 
#' ## Exercice 1
#' Voici une variable "x" représentant le temps de survie d'insectes après la ponte.
#' 
#' * Tracez un histogramme de fréquence de ces valeurs, ensuite calculez la moyenne, 
#' la médiane, les quantiles à 2.5% et 97.5%  (= 0.9125, 26.37) et l'écart type des données
#' * Estimez l'erreur standard et l'intervalle de confiance de la médiane avec la méthode 
#' du bootsrap vue pendant la partie théorique (NB : il n'existe pas de formule mathématique 
#' permettant de calculer ces valeurs comme pour la moyenne)
#' * Est-ce qu'on pourrait dans ce cas calculer un intervalle de confiance sur la moyenne 
#' avec la méthode paramétrique (en utilisant l'erreur standard divisée par la racine carrée du nombre d'observations) ?
#' * transformez la variable au moyen du logarithme népérien (fonction log). 
#' Tracez un histogramme de cette nouvelle variable et calculez la moyenne et la médianne.
#' * Calculez l'erreur standard (0.121194) et l'intervalle de confiance (1.2707 - 1.798) 
#' de la moyenne de cette nouvelle variable
#' avec la méthode paramétrique. Pourquoi peut-on le faire dans ce cas ? Comparez avec 
#' les mêmes valeurs obtenues par bootstrap.
#' 
#+ echo=TRUE
set.seed(123)
x <- round(exp(rnorm(50, 1.5, 1)),1)
x

#'  
mean(x)
median(x)
quantile(x, probs = c(0.025, 0.975))
sd(x)

# graphique
hist(x, main = "")
abline(v = mean(x), col = "red")
mtext(text="moyenne", side=3, line= 0, at=mean(x), col = "red")
abline(v = median(x), col = "red")
mtext(text="médiane", side=3, line= 1, at=median(x), col = "red")

# bootsrap
boot <- replicate(1000, median(sample(x, replace = TRUE)))
sd(boot)
quantile(boot, probs = c(0.025, 0.975))

# On ne peut clairement pas utiliser la méthode paramétrique ici pour estimer l'intervalle 
# de confiance sur la moyenne car cette méthode suppose que la population est distribuée 
# selon une loi normale ce qui n'est clairement pas le cas ici

# transformation

x <- log(x)
mean(x)
median(x)
hist(x, main = "")
abline(v = mean(x), col = "red")
mtext(text="moyenne", side=3, line= 0, at=mean(x), col = "red")
abline(v = median(x), col = "red")
mtext(text="médiane", side=3, line= 1, at=median(x), col = "red")

# se et CI de la variable transformée
t.test(x)# fourni l'intervalle de confiance

(se.x <- sd(x)/sqrt(length(x)))  # erreur standard de la moyenne

mean(x) + qt(p=0.025, df = length(x)-1) * se.x
mean(x) + qt(p=0.975, df = length(x)-1) * se.x

# bootsrap
boot <- replicate(1000, mean(sample(x, replace = TRUE)))
sd(boot)
quantile(boot, probs = c(0.025, 0.975))



#' 
##' <!-- page break -->

#' 
#' ## Exercice 2
#' Voici deux variables contenant la production laitaire de 25 vaches controles et 25 
#' vaches traitées.
#' 
#' * Faites une représentation graphique des données (par exemple un boxplot)
#' * Utilisez la fonction de R pour réaliser un test de student comparant les moyennes 
#' de ces deux groupes. 
#' Utilisez l'option var.equal = TRUE (les variances des deux groupes sont considérées comme égales).
#' Comment interprétez-vous les résultats? (p = 0.02092)
#' * Recalculez vous-même les valeurs de t, les degrés de liberté et la p-valeur. 
#' La formule du test de student comparant 2 moyennes se trouve dans la présentation, diapo 52.
#' * recalculez la p-valeur de ce test par permutation

#+ echo=TRUE
n <- 25
set.seed(1)
control <- abs(rnorm(n, 20, 5))
set.seed(12)
treatment <- abs(rnorm(n, 25,5))

#'   
# graphique
boxplot(control, treatment)

# test de student
t.test(control, treatment, var.equal=TRUE)

# Calcul à la main
(tstat <- (mean(control) - mean(treatment))/ sqrt((var(control)/length(control)) + 
                                                      (var(treatment)/length(treatment))))
(ddl <- length(control) + length(treatment) - 2)
(p <- 2*pt(tstat, ddl, lower.tail=TRUE))

# test par permutation - approche 1 avec la fonction replicate
d <- c(control, treatment)
group <- as.factor(c(rep("control", length(control)), rep("treatment", length(control))))

perm <- replicate (999, t.test( d ~ sample(group, replace = FALSE), var.equal=TRUE)$statistic)
perm <- c(perm, tstat)
sum(abs(perm) >= abs(tstat))/1000

# test par permutation - approche 2 avec une boucle
d <- c(control, treatment)

perm <- vector(length = 1000)
for (i in 1: 999) {
    d <- sample(c(control, treatment))
    permcontrol <- d[1:length(control)]
    permtreatment <- d[length(control):length(d)]
    perm [i] <- t.test(permcontrol, permtreatment, var.equal = FALSE)$statistic
}
perm <- c(perm, tstat)
sum(abs(perm) >= abs(tstat))/1000




